==> nomachine-8.3.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Common/DesktopMode.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package Common::DesktopMode;no warnings;($DesktopMode::ViewOnlyValue=
(0x0f5a+ 5547-0x2505));($DesktopMode::ViewOnlyString=
"\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79");($DesktopMode::RestrictedValue=
(0x0c69+ 1804-0x1374));($DesktopMode::RestrictedString=
"\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64");($DesktopMode::InteractiveValue=
(0x0aac+ 3286-0x1780));($DesktopMode::InteractiveString=
"\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65");sub getViewOnlyValue{return (
$DesktopMode::ViewOnlyValue);}sub getRestrictedValue{return (
$DesktopMode::RestrictedValue);}sub getInteractiveValue{return (
$DesktopMode::InteractiveValue);}sub convertShadowModeToText{(my $value=shift (
@_));if ((($value eq $DesktopMode::ViewOnlyString)or ($value eq 
$DesktopMode::ViewOnlyValue))){return ($DesktopMode::ViewOnlyString);}elsif (((
$value eq $DesktopMode::RestrictedString)or ($value eq 
$DesktopMode::RestrictedValue))){return ($DesktopMode::RestrictedString);}elsif 
((($value eq $DesktopMode::InteractiveString)or ($value eq 
$DesktopMode::InteractiveValue))){return ($DesktopMode::InteractiveString);}
Logger::error (
"\x4f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x64\x65\x73\x6b\x74\x6f\x70\x20\x6d\x6f\x64\x65\x2e"
);
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x43\x6f\x6e\x66\x69\x67\x75\x72\x61\x74\x69\x6f\x6e"
->throw (
"\x6f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x27\x53\x65\x73\x73\x69\x6f\x6e\x53\x68\x61\x64\x6f\x77\x4d\x6f\x64\x65\x27\x20\x6b\x65\x79"
);return ((""));}sub getShadowingModeValue{(my $value=shift (@_));if ((($value 
eq $DesktopMode::ViewOnlyString)or ($value eq $DesktopMode::ViewOnlyValue))){
return ((0x192a+ 2821-0x242f));}elsif ((($value eq 
$DesktopMode::RestrictedString)or ($value eq $DesktopMode::RestrictedValue))){
return ((0x050f+ 3476-0x12a2));}elsif ((($value eq 
$DesktopMode::InteractiveString)or ($value eq $DesktopMode::InteractiveValue))){
return ((0x0871+ 2889-0x13b8));}Logger::error (
"\x4f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x64\x65\x73\x6b\x74\x6f\x70\x20\x6d\x6f\x64\x65\x2e"
);
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x43\x6f\x6e\x66\x69\x67\x75\x72\x61\x74\x69\x6f\x6e"
->throw (
"\x6f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x27\x53\x65\x73\x73\x69\x6f\x6e\x53\x68\x61\x64\x6f\x77\x4d\x6f\x64\x65\x27\x20\x6b\x65\x79"
);return ((""));}sub isInteractive{(my $value=shift (@_));if ((($value eq 
$DesktopMode::InteractiveString)or ($value eq $DesktopMode::InteractiveValue))){
return ((0x12cd+ 4717-0x2539));}return ((0x0b87+  22-0x0b9d));}return (
(0x0667+ 5142-0x1a7c));

==> nomachine-8.11.3-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Common/DesktopMode.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package Common::DesktopMode;no warnings;($DesktopMode::ViewOnlyValue=
(0x0010+ 3177-0x0c79));($DesktopMode::ViewOnlyString=
"\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79");($DesktopMode::RestrictedValue=
(0x13c7+  95-0x1425));($DesktopMode::RestrictedString=
"\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64");($DesktopMode::InteractiveValue=
(0x0df9+ 6158-0x2605));($DesktopMode::InteractiveString=
"\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65");sub getViewOnlyValue{return (
$DesktopMode::ViewOnlyValue);}sub getRestrictedValue{return (
$DesktopMode::RestrictedValue);}sub getInteractiveValue{return (
$DesktopMode::InteractiveValue);}sub convertShadowModeToText{(my $value=shift (
@_));if ((($value eq $DesktopMode::ViewOnlyString)or ($value eq 
$DesktopMode::ViewOnlyValue))){return ($DesktopMode::ViewOnlyString);}elsif (((
$value eq $DesktopMode::RestrictedString)or ($value eq 
$DesktopMode::RestrictedValue))){return ($DesktopMode::RestrictedString);}elsif 
((($value eq $DesktopMode::InteractiveString)or ($value eq 
$DesktopMode::InteractiveValue))){return ($DesktopMode::InteractiveString);}
Logger::error (
"\x4f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x64\x65\x73\x6b\x74\x6f\x70\x20\x6d\x6f\x64\x65\x2e"
);
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x43\x6f\x6e\x66\x69\x67\x75\x72\x61\x74\x69\x6f\x6e"
->throw (
"\x6f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x27\x53\x65\x73\x73\x69\x6f\x6e\x53\x68\x61\x64\x6f\x77\x4d\x6f\x64\x65\x27\x20\x6b\x65\x79"
);return ((""));}sub getShadowingModeValue{(my $value=shift (@_));if ((($value 
eq $DesktopMode::ViewOnlyString)or ($value eq $DesktopMode::ViewOnlyValue))){
return ((0x19c6+ 1493-0x1f9b));}elsif ((($value eq 
$DesktopMode::RestrictedString)or ($value eq $DesktopMode::RestrictedValue))){
return ((0x0b69+ 1860-0x12ac));}elsif ((($value eq 
$DesktopMode::InteractiveString)or ($value eq $DesktopMode::InteractiveValue))){
return ((0x0f23+ 2650-0x197b));}Logger::error (
"\x4f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x64\x65\x73\x6b\x74\x6f\x70\x20\x6d\x6f\x64\x65\x2e"
);
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x43\x6f\x6e\x66\x69\x67\x75\x72\x61\x74\x69\x6f\x6e"
->throw (
"\x6f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x27\x53\x65\x73\x73\x69\x6f\x6e\x53\x68\x61\x64\x6f\x77\x4d\x6f\x64\x65\x27\x20\x6b\x65\x79"
);return ((""));}sub isInteractive{(my $value=shift (@_));if ((($value eq 
$DesktopMode::InteractiveString)or ($value eq $DesktopMode::InteractiveValue))){
return ((0x21e1+ 818-0x2512));}return ((0x0e97+  33-0x0eb8));}return (
(0x0248+ 1703-0x08ee));
